==> scipion-em-reliontomo-3.1.1.tar.gz: scipion-em-reliontomo-3.1.1/reliontomo/protocols/protocol_import_coordinates_from_star.py <==
# *
# * Authors:     Scipion Team
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion-users@lists.sourceforge.net'
# *
# **************************************************************************
from enum import Enum
from reliontomo.protocols.protocol_base_import_from_star import ProtBaseImportFromStar
from tomo.objects import SetOfTomograms, SetOfCoordinates3D


class outputObjects(Enum):
    tomograms = SetOfTomograms()
    coordinates = SetOfCoordinates3D()


class ProtImportCoordinates3DFromStar(ProtBaseImportFromStar):
    """Protocol to import a set of 3D coordinates from a star file"""

    _label = 'import coordinates 3D from a star file'
    _possibleOutputs = outputObjects

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.linkedStarFileName = 'in3dCoordinates.star'

==> scipion-em-reliontomo-4.0.0.tar.gz: scipion-em-reliontomo-4.0.0/reliontomo/protocols/protocol_import_coordinates_from_star.py <==
# *
# * Authors:     Scipion Team
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion-users@lists.sourceforge.net'
# *
# **************************************************************************
from enum import Enum

from pyworkflow import BETA, PROD
from reliontomo import Plugin
from reliontomo.protocols.protocol_base_import_from_star import ProtBaseImportFromStar
from tomo.objects import SetOfTomograms, SetOfCoordinates3D

IS_RELION_50 = Plugin.isRe50()


class outputObjects(Enum):
    tomograms = SetOfTomograms()
    coordinates = SetOfCoordinates3D()


class ProtImportCoordinates3DFromStar(ProtBaseImportFromStar):
    """Protocol to import a 3D coordinates from a relion star file as the one provided in the tutorial"""

    _label = 'import 3D coordinates from a star file'
    _devStatus = BETA if IS_RELION_50 else PROD
    _possibleOutputs = outputObjects

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.isCoordsFile = True
